@@ -11,7 +11,6 @@ from retry import retry
 import requests
 from otel_extensions import instrumented
 from opentelemetry import trace
-from random import random
 
 from utf_queue_client.utils import prepare_queue_central_url
 
@@ -80,10 +79,10 @@ def cli(
             else:
                 upload_artifact_direct(file_path, metadata_dict)
 
-        # load mitigation
-        sleep(random() * 2.5)
         retry_wrapper()
-        sleep(random() * 2.5)
+        if not queue:
+            # workaround to reduce load
+            sleep(2)
 
 
 @instrumented
